// Point.h: interface for the Point class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_POINT_H__1D4FA640_6BA6_11D5_923F_00A024900B4B__INCLUDED_)
#define AFX_POINT_H__1D4FA640_6BA6_11D5_923F_00A024900B4B__INCLUDED_

#include "Vector.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class	Point {
	
private :
	
	double		_x, _y, _z ;
	
public :
	
	//  Constructors
	
	Point () ;
	
	Point ( const double, 
		const double = 0.0, 
		const double = 0.0 ) ;
	
	//  Copy Constructor
	
	Point ( const Point& ) ;
	
	//  Destructor
	
	virtual ~Point () ;
	
	//  Assignment
	
	Point& operator= ( const Point& ) ;
	
	//  Comparison
	
	friend int operator== ( const Point&, const Point& ) ;
	friend int operator!= ( const Point&, const Point& ) ;
	
	//  Arithmetic Operations
	
	friend Point operator+ ( const Point&, const Vector& ) ;
	friend Point operator+ ( const Vector&, const Point& ) ;
	friend Vector operator- ( const Point&, const Point& ) ;
	friend Point operator- ( const Point&, const Vector& ) ;
	friend Point operator- ( const Point& ) ;
	
	Point& operator+= ( const Vector& ) ;
	Point& operator-= ( const Vector& ) ;
	
	//  Affine Combinations
	
	friend Point affine ( const Point&, 
		const Point&, 
		const double ) ;
	
	friend Point affine ( const Point&, 
		const Point&, 
		const Point&, 
		const double,
		const double,
		const double ) ;
	
	friend Point average ( Point *, const int ) ;
	friend Point midpoint ( const Point&, const Point& ) ;
	
	//  Access Functions
	
	double x () const { return _x ; } ;
	double y () const { return _y ; } ;
	double z () const { return _z ; } ;
	
} ;

const Point PointZero ( 0.0, 0.0, 0.0 ) ;

#endif // !defined(AFX_POINT_H__1D4FA640_6BA6_11D5_923F_00A024900B4B__INCLUDED_)
